/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Jan 24, 2003
 * Copyright (C) 2002  Aditisoft Inc
 */
package com.aditisoft.editor;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JToolBar;

/**
 * @author Anil K Patel
 * 
 * Toolbar containing the title of page and list of all master templates.
 */
public class DocAttributeToolbar extends JToolBar implements ActionListener {

	/** Represent the structure of page */
	CmsDocument mDoc;
	/** Used to show Title of page */
	JTextField txtTitle;
	/** Show list of all available master templates */
	JComboBox cboTemplateList;

	/**
	 * Empty Constructor DocAttributeToolbar.
	 */
	public DocAttributeToolbar() {
		super();
		JPanel p = new JPanel();
		p.add(new JLabel("Title"));
		txtTitle = new JTextField(20);
		p.add(txtTitle);
		add(p);
		p = new JPanel();
		p.add(new JLabel("Master Template"));
		cboTemplateList = new JComboBox();
		cboTemplateList.addActionListener(this);
		p.add(cboTemplateList);
		add(p);
	}

	/**
	 * Method init initialize the title field and list of master templates.
	 * @param doc document structure of page.
	 */
	public void init(CmsDocument doc) {
		mDoc = doc;
		if (doc != null) {
			txtTitle.setText(doc.getDocumentTitle());

			cboTemplateList.setModel(new DefaultComboBoxModel(doc.getAllTemplates()));
			cboTemplateList.setSelectedItem(doc.getMasterTemplateTitle());
		}
	}

	/**
	 * Method getTitle gets the value of title field.
	 * @return String returns the value of title field.
	 */
	public String getTitle() {
		return txtTitle.getText();
	}

	/**
	 * Method getMasterTemplate gets the name of master template.
	 * @return String returns the name of master template.
	 */
	public String getMasterTemplate() {
		return mDoc.getMasterTemplateName();
	}

	/**
	 * Sets the master template of document with selected item.
	 * @see java.awt.event.ActionListener#actionPerformed(ActionEvent)
	 */
	public void actionPerformed(ActionEvent evt) {
		JComboBox comboBox = (JComboBox) evt.getSource();
		mDoc.setMasterTemplate((String) comboBox.getSelectedItem());
	}
}
