/**
 * Created on Dec 4, 2002
 *This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/**
  * @author Anil K Patel Dec 04 2002
 * Copyright (C) 2002 Aditisoft Inc
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 */

package com.aditisoft.editor;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JComboBox;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JToolBar;
import javax.swing.border.Border;
import com.aditisoft.ui.GenericListener;

/**
 * @author Anil K Patel 
 * Copyright (C) 2002 Aditisoft Inc
 * 
 */

/**
 * Toolbar for WYSIWYG editor containing actions like bold,italic,underline. 
 */
public class FormatToolbar extends Toolbar {
	/** Editor that execute all the actions. */
	private EditorActions mEditorActions;

	/**
	 * Create instance of FormatToolbar.
	 * @param actions Editor that execute all the actions.
	 */
	public FormatToolbar(EditorActions actions) {
		mEditorActions = actions;

		JButton fontsize = createButton("Font Size", "largefont_edit.gif");
      bindActionListener(fontsize,"setSize");
		add(fontsize);
		
      JButton bold = createButton("Bold", "bu_bold.gif");
      bindActionListener(bold,"setBold");
		add(bold);
      
		JButton italic = createButton("Italic", "bu_italic.gif");
      bindActionListener(italic,"setItalic");
		add(italic);

		JButton underline = createButton("Underline", "bu_underline.gif");
      bindActionListener(underline,"setUnderline");
		add(underline);

		JButton fontcolor = createButton("Font Color", "bu_color_text.gif");
      bindActionListener(fontcolor,"setColor");
		add(fontcolor);

		JComboBox fontOptions = new JComboBox();
		addFontOptions(fontOptions);
		fontOptions.addActionListener(GenericListener.createActionListener(this, "setFont"));
		add(fontOptions);

		JButton subscript = createButton("Subscript", "sbscript_edit.gif");
      bindActionListener(subscript,"setSubscript");
		add(subscript);

		JButton superscript = createButton("Superscript", "sscript_edit.gif");
      bindActionListener(superscript,"setSuperscript");
		add(superscript);

		JButton horizontalrule = createButton("Horizontal Rule", "horzrule_edit.gif");
      bindActionListener(horizontalrule,"setHorizontal");
		add(horizontalrule);

		JButton paragraph = createButton("P");
		paragraph.setToolTipText("Paragraph");
      bindActionListener(paragraph,"setParagraph");
		add(paragraph);

		JButton breakb = createButton("Break", "break_edit.gif");
      bindActionListener(breakb,"setBreak");
		add(breakb);

		JButton nonbreak = createButton("Non-Breaking Space", "XSDWhiteSpaceFacet.gif");
      bindActionListener(nonbreak,"setNonBreak");
		add(nonbreak);

		JButton aleft = createButton("Align Left", "bu_left.gif");
      bindActionListener(aleft,"setLeft");
		add(aleft);

		JButton acenter = createButton("Align Center", "bu_center.gif");
      bindActionListener(acenter,"setCenter");
		add(acenter);

		JButton aright = createButton("Align Right", "bu_right.gif");
      bindActionListener(aright,"setRight");
		add(aright);

	}

	private void addFontOptions(JComboBox fontOptionsBox) {
		fontOptionsBox.addItem("Arial");
		fontOptionsBox.addItem("Arial Narrow");
		fontOptionsBox.addItem("Monospaced");
		fontOptionsBox.addItem("Serif");
		fontOptionsBox.addItem("SansSerif");
		fontOptionsBox.addItem("System");
		fontOptionsBox.addItem("Times New Roman");
		fontOptionsBox.addItem("Verdana");
	}

	public void setFont(ActionEvent event) {
		JComboBox source = (JComboBox) event.getSource();
		String item = (String) source.getSelectedItem();
		mEditorActions.setFont(item);
	}

	public void setSize(ActionEvent event) {
		new FontPopup(mEditorActions).show(this, 0, 30);
	}
	public void setBold(ActionEvent event) {
		mEditorActions.setBold();
	}
	public void setItalic(ActionEvent event) {
		mEditorActions.setItalic();
	}
	public void setUnderline(ActionEvent event) {
		mEditorActions.setUnderline();
	}
	public void setColor(ActionEvent event) {
		Color newColor = JColorChooser.showDialog(this, "Choose Font Color", null);
		mEditorActions.setColor(newColor);
	}
	public void setSubscript(ActionEvent event) {
		mEditorActions.setSubscript();
	}
	public void setSuperscript(ActionEvent event) {
		mEditorActions.setSuperscript();
	}
	public void setHorizontal(ActionEvent event) {
		mEditorActions.setHorizontal();
	}
	public void setParagraph(ActionEvent event) {
		mEditorActions.setParagraph();
	}
	public void setBreak(ActionEvent event) {
		mEditorActions.setBreak();
	}
	public void setNonBreak(ActionEvent event) {
		mEditorActions.setNonBreak();
	}
	public void setLeft(ActionEvent event) {
		mEditorActions.setLeft();
	}
	public void setCenter(ActionEvent event) {
		mEditorActions.setCenter();
	}
	public void setRight(ActionEvent event) {
		mEditorActions.setRight();
	}

	/**
	 * Internal method to create Button.
	 * @param text Text for button.     
	 * @return JButton
	 */
	private JButton createButton(String text) {
		Border blackline = BorderFactory.createLineBorder(Color.black);
		JButton button = new JButton(text);
		button.setBorder(blackline);
		return button;
	}
}

/**
 * This class is a popup menu for font sizes.  It allows the user to select what size they
 * want their selected text.
 */
class FontPopup extends JPopupMenu {
	/**
	 * Creates the font popup.
	 *
	 * @param tree editor to change the fonts size of.  I'm not sure why I called it tree.
	 */
	public FontPopup(EditorActions actions) {
		super();

		FontPopupActions fEventListener = new FontPopupActions(actions);
		//Create Menu items
		JMenuItem plus1 = new JMenuItem("+1");
		plus1.addActionListener(fEventListener);
		add(plus1);
		JMenuItem plus2 = new JMenuItem("+2");
		plus2.addActionListener(fEventListener);
		add(plus2);
		JMenuItem plus3 = new JMenuItem("+3");
		plus3.addActionListener(fEventListener);
		add(plus3);
		JMenuItem zero = new JMenuItem("+0");
		zero.addActionListener(fEventListener);
		add(zero);
		JMenuItem minus1 = new JMenuItem("-1");
		minus1.addActionListener(fEventListener);
		add(minus1);
		JMenuItem minus2 = new JMenuItem("-2");
		minus2.addActionListener(fEventListener);
		add(minus2);
		JMenuItem minus3 = new JMenuItem("-3");
		minus3.addActionListener(fEventListener);
		add(minus3);
	}
}

/**
 * This class will actual call functions to change the font once a font size is selected
 * from the popup menu
 */
class FontPopupActions implements ActionListener {
	/** Class to perform actions. */
	private EditorActions mEditorActions;

	/**
	 * Creates handler to perform font actions.
	 *
	 * @param edit Editor to perform action on.
	 */
	public FontPopupActions(EditorActions actions) {
		super();
		mEditorActions = actions;
	}

	/**
	 * Performs the action on the selected text.
	 *
	 * @param e The ActionEvent that occurred.
	 */
	public void actionPerformed(ActionEvent e) {
		String size = e.getActionCommand();

		// This jazz converts sizes to a format that StyledEditor.FontSizeAction
		// likes
		if (size.equals("-3")) {
			size = "8";
		}
		else if (size.equals("-2")) {
			size = "10";
		}
		else if (size.equals("-1")) {
			size = "12";
		}
		else if (size.equals("+0")) {
			size = "14";
		}
		else if (size.equals("+1")) {
			size = "16";
		}
		else if (size.equals("+2")) {
			size = "24";
		}
		else if (size.equals("+3")) {
			size = "32";
		}
		else { // Default size
			size = "14";
		}
		mEditorActions.setSize(size);
	}
}
