// This code has been adoped from Curriculum Development Tool

package com.aditisoft.editor;

import java.awt.Color;
import java.awt.Toolkit;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;
import java.util.Arrays;
import java.util.Iterator;

import javax.swing.JTextPane;
import javax.swing.event.UndoableEditEvent;
import javax.swing.event.UndoableEditListener;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.html.HTMLEditorKit;
import javax.swing.undo.UndoManager;

/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * WYSIWYG editor for HTML content. 
 * @version 1.0
 * @author Anil K Patel
 */
public class HTMLEditor extends JTextPane implements UndoableEditListener, ITextEditor {
	/** Frame that this editor is in. */
	//    private JFrame parent;
	/** This object handles all our undo/redo stuff really easily. */
	private UndoManager mUndoManager;
	//	private HTMLEditorInputHandler inputHandler;
	/**
	 */
	public HTMLEditor() {
		super();
		this.setEditorKit(new HTMLEditorKit());
		this.setEditable(false);
		this.setBackground(Color.lightGray);
		mUndoManager = new UndoManager();
		getDocument().addUndoableEditListener(mUndoManager);
	}


	/**
	 * This resets the view of the editor.  I know what your thinking.  What does that mean??
	 * Well a JTextPane can behave very strangely when you try to do the kind of things we're
	 * doing to it.  And one of those is not displaying right when certain things are done to
	 * it.  I don't know why but for some reason getting the text of the editor and setting
	 * the text editor to that same text fixes some of the viewing problems. So that is why
	 * this function is here.
	 */
	public void reset() {
		String html = getText();
		setText(html);

	//	resetUndos();
	}

	/**
	 * This just checks whether the editor has a file to edit or not.
	 *
	 * @return where the editor has a file to edit.
	 */
	public boolean isClosed() {
		return !isEditable();
	}

	/**
	 * This removes the file being edited.  It also changes the background and does not let
	 * the editor be edited.
	 */
	public void close() {
		setText("");
		setEditable(false);
		setBackground(Color.lightGray);
		resetUndos();
	}

	public void setEditText(String text) {
		setText(text);

		//make sure that everything can be edited and looks right
		this.setEditable(true);
		this.setBackground(Color.white);
		this.setCaretPosition(0);
		// they've opened a new file so we need to start undo all over
		resetUndos();
	}

	public String getHtmlText() {
		return getText();
	}

	/**
	 * Performs the undo command.
	 */
	public void undo() {
		try {
			if (mUndoManager.canUndo()) {
				mUndoManager.undo();
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Performs the redo command.
	 */
	public void redo() {
		try {
			boolean needToToggleUndo = false;
			if (mUndoManager.canRedo()) {
				mUndoManager.redo();
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void paste() {
		super.paste();
      reset();
	}

	/**
		 * Used to re-enable the JMenuItem for 'undo' when an undoable edit occurs.
		 * Since this is only relevant if 'undo' is disabled, it will remove itself
		 * from the document's undoableEditorListener list once it executes (and when
		 * undo is disabled later, it will get re-added).
		 *
		 * @param e An event representing an undoable edit that occured in the
		 *		document.
		 */
	public void undoableEditHappened(UndoableEditEvent e) {
		// Makes sure this is not set as an UndoableEditListener if appropriate
		if (!mUndoManager.canUndo()) {
			getDocument().removeUndoableEditListener(this);
		}
	}

	/**
	 * Resets the UndoManager and (attempts to) set up the EditMenu correctly.
	 */
	private void resetUndos() {
		if (!mUndoManager.canUndo()) {
			getDocument().removeUndoableEditListener(this);
		}
		mUndoManager.discardAllEdits();
		getDocument().addUndoableEditListener(this);
	}

	public void select(int start, int end) {
		setCaretPosition(start);
		moveCaretPosition(end);
		repaint();
	}

	public int find(String stringToFind) {
		requestFocus();
		int startIndex = -1;
		int subDocStartLoc = getCaretPosition();
		if (!(getDocument().getLength() > subDocStartLoc)) {
			subDocStartLoc = 0;
		}
		try {
			startIndex =
				getDocument().getText(0, getDocument().getLength()).toLowerCase().indexOf(
					stringToFind.toLowerCase(),
					subDocStartLoc);
			if (startIndex != -1) {
				int endIndex = startIndex + stringToFind.length();
				select(startIndex, endIndex);
			}
		}
		catch (BadLocationException e) {
			e.printStackTrace();
			//Do nothing, Mey never get thrown
		}
		return startIndex;
	}

	public int getIndexOf(String stringToFind) {
		int returnVal = -1;
		try {
			returnVal =
				getDocument().getText(0, getDocument().getLength()).toLowerCase().indexOf(
					stringToFind.toLowerCase(),
					getCaretPosition());
		}
		catch (BadLocationException e) {
			e.printStackTrace();
			//Do nothing, Mey never get thrown
		}
		return returnVal;
	}

	/**
	 * Method replace.
	 * @param stringToFind
	 * @param replaceWith
	 * @param replaceAll
	 */
	public void replace(String stringToFind, String replaceWith, boolean replaceAll) {
		if (replaceAll) {
			setCaretPosition(0);
		}
		do {
			replace(stringToFind, replaceWith);
		}
		while ((getIndexOf(stringToFind) != -1) && replaceAll);
	}

	public void replace(String stringToFind, String replaceWith) {
		requestFocus();
		int findPosition = getIndexOf(stringToFind);
		if (findPosition != -1) {
			try {
				Document doc = getDocument();
				//            select(findPosition, stringToFind.length());
				doc.remove(findPosition, stringToFind.length());
				doc.insertString(findPosition, replaceWith, getCharacterAttributes());
				setCaretPosition(findPosition + replaceWith.length());
			}
			catch (BadLocationException e) {
				//Should not happen
				e.printStackTrace();
			}
		}
	}

}
