/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Dec 4, 2002
 *
 * @author Anil K Patel Dec 04 2002
 * Copyright (C) 2002 Aditisoft Inc
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 */

package com.aditisoft.editor;

import java.awt.BorderLayout;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
/**
 *  This is the toolbar panel for WYSIWYG editor. 
 */

public class HTMLEditorPanel extends JPanel implements IEditorTools {

	/** The JTextPane that is being edited. */
	HTMLEditor mEditor;
	/** Toolbar to set title and master template */
	DocAttributeToolbar mDocAttributes;
	/** Document containing informations of page and master template */
	CmsDocument mCmsDocument;

	/**
	 * Creates an instance of EditorPanel.
	 *
	 * @param fileActions IFileActionsListener.
	 */
	public HTMLEditorPanel(IFileActionsListener fileActions) {
		super();
		mEditor = new HTMLEditor();
		EditorActions editorActions = new EditorActions(mEditor);
		mEditor.addKeyListener(new KeyEventListener(editorActions));
		ModFlowLayout layoutManager = new ModFlowLayout(ModFlowLayout.LEFT);
		layoutManager.setParent(this);
		JPanel toolBarPanel = new JPanel();
		toolBarPanel.setLayout(layoutManager);
		toolBarPanel.add(new FileToolbar(fileActions));
		toolBarPanel.add(new EditToolbar(mEditor));
		toolBarPanel.add(new SearchToolbar(this));
		toolBarPanel.add(new FormatToolbar(editorActions));
		toolBarPanel.add(new ListToolbar(editorActions));
		toolBarPanel.add(new WizardToolbar(editorActions));
		mDocAttributes = new DocAttributeToolbar();
		toolBarPanel.add(mDocAttributes);
		mDocAttributes.init(null);

		setLayout(new BorderLayout());
		add(toolBarPanel, BorderLayout.NORTH);
		add(new JScrollPane(mEditor), BorderLayout.CENTER);
		mEditor.setEditText("");
	}

	/**
	 * Returns the mEditor.
	 * @return HTMLEditor
	 */
	public HTMLEditor getEditor() {
		return mEditor;
	}

	/**
	 * Method setCmsDocument sets the CmsDocument.
	 * @param doc
	 */
	public void setCmsDocument(String doc) {
		mCmsDocument = CmsDocument.getDocument(doc);
		mEditor.setEditText(mCmsDocument.getDocumentBody());
		mDocAttributes.init(mCmsDocument);
	}

	/**
	 * Method getContentText.
	 * @return String
	 */
	public String getContentText() {
		return mEditor.getText();
	}

	/**
	 * Return Document title
	 */
	public String getTitle() {
		return mDocAttributes.getTitle();
	}
	/**
	 * Get Master template for the Document
	 */
	public String getMasterTemplate() {
		return mDocAttributes.getMasterTemplate();
	}
   
	public void showFindDialog() {
		SearchDialog searchDialog = new SearchDialog(this, mEditor);
		searchDialog.show();
	}
   
	public void showReplaceDialog() {
		ReplaceDialog replaceDialog = new ReplaceDialog(this, mEditor);
		replaceDialog.show();
	}

}
