package com.aditisoft.editor;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.util.Arrays;

/**
 * This class is used to call <code>importData(JComponent, Transferable)</code> with modified HTML.
 * The only reason I have it is so that I can get pasting to work correctly with MS Word.
 *
 * @version 1.0
 * @author Brad Schaefer (<A HREF="mailto:schaefer@medstat.med.utah.edu">schaefer@medstat.med.utah.edu</A>)
 * @see cdt.editor.EditorActions#paste
 */
public class HtmlTransfer implements Transferable
{

	/** the html Data we are transfering. */
	private String html;
	private static DataFlavor HtmlFlavor;

	static {
		try
		{
			HtmlFlavor = new DataFlavor("text/html; class=java.lang.String");
		} catch (Exception e)
		{
			e.printStackTrace();
			HtmlFlavor = DataFlavor.stringFlavor;
		}
	}

	/** The transferable DataFlavors of this object */
	private static DataFlavor[] flavors = { HtmlFlavor };

	/**
	 * Creates an HtmlTransfer object.
	 *
	 * @param html Html to store.
	 */
	public HtmlTransfer(String html)
	{
		this.html = html;
	}

	/**
	 * Gets the Html that is stored.
	 *
	 * @param flavor Requested DataFlavor of the transfer data.
	 * @throws UnsupportedFlavorException
	 * @return Html stored in this object.
	 */
	public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException
	{
		if (flavor == HtmlFlavor)
		{
			return html;
		}
		throw new UnsupportedFlavorException(flavor);
	}

	/**
	 * Gets an array of supported DataFlavors.
	 *
	 * @return array of supported DataFlavors.
	 */
	public DataFlavor[] getTransferDataFlavors()
	{
		return flavors;
	}

	/**
	 * Gets where a DataFlavor is supported by this Transferable object.
	 *
	 * @param flavor DataFlavor to check for support.
	 * @return Whether the DataFlavor is supported.
	 */
	public boolean isDataFlavorSupported(DataFlavor flavor)
	{
		return Arrays.asList(flavors).contains(flavor);
	}
}
