package com.aditisoft.editor;

import javax.swing.text.BadLocationException;

/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * @author Anil K Patel Dec 02 2002
 * Copyright (C) 2002 Aditisoft Inc
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 */
public interface ITextEditor {

	/**
	 * Performs the undo command.
	 *
	 * @return Whether it was successful.
	 */
	public void cut();

	/**
	 * Performs the undo command.
	 *
	 * @return Whether it was successful.
	 */
	public void paste();

	/**
	 * Performs the undo command.
	 *
	 * @return Whether it was successful.
	 */
	public void copy();

	/**
	 * Performs the redo command.
	 *
	 * @return Whether it was successful.
	 */
	public void redo();

	/**
	 * Performs the undo command.
	 *
	 * @return Whether it was successful.
	 */
	public void undo();

	/**
	    * Selects from the start offset to the end offset. This is the
	    * general selection method used by all other selecting methods.
	    * The caret position will be start if start &lt; end, and end
	    * if end &gt; start.
	    * @param start The start offset
	    * @param end The end offset
	    */
	public void select(int start, int end);

/**
    * Returns the caret position. This will either be the selection
    * start or the selection end, depending on which direction the
    * selection was made in.
    */
   public int getCaretPosition() ;

   public void setCaretPosition(int location) ;


/**
    * Returns the entire text of this text area.
    */
   public String getText() ;
   /**
    * Sets the entire text of this text area.
    */
//   public void setText(String text) ;

   /**
    * Returns the specified substring of the document.
    * @param start The start offset
    * @param len The length of the substring
    * @return The substring, or null if the offsets are invalid
    */
   public String getText(int start, int len) throws BadLocationException   ;

/**
     * Returns the selected text contained in this
     * <code>TextComponent</code>.  If the selection is 
     * <code>null</code> or the document empty, returns <code>null</code>.
     *
     * @return the text
     * @exception IllegalArgumentException if the selection doesn't
     *  have a valid mapping into the document for some reason
     * @see #setText
     */
    public String getSelectedText();
    
    /**
     * Returns the selected text's start position. Return 0 for an empty document, or the value of dot if no selection. 
     */
    public int getSelectionStart();
    
	/**
	 * Find the given text and make it selected.
	 * @param stringToFind string to find.
	 */
	public int find(String stringToFind);

	/**
	 * Replace the selected string with given new string.
	 * @param stringToFind string that has to be replaced.
	 * @param replaceWith new string to be inserted.
	 * @param replaceAll indicate if replace all the occurance.
	 */
	public void replace(String stringToFind, String replaceWith, boolean replaceAll);

//	public void showFindDialog();
//	public void showReplaceDialog();
}
