package com.aditisoft.editor;

import java.awt.event.ActionEvent;

import javax.swing.JEditorPane;
import javax.swing.JTextPane;
import javax.swing.UIManager;
import javax.swing.text.AttributeSet;
import javax.swing.text.JTextComponent;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledEditorKit;

/**
 * A StyledEditorKit.StyledTextAction used in
 * {@link cdt.editor.EditorActions EditorActions} to change the
 * style of the text to be indented either leftwards or rightwards.
 */
public class IndentAction extends StyledEditorKit.StyledTextAction {

	/**
	 * The String that represents an action that indents the text in the
	 * left-hand direction.
	 */
	public static final String LEFT = new String("font-indent-left"); // -50;
	/**
	 * The String that represents an action that indents the text in the
	 * right-hand direction.
	 */
	public static final String RIGHT = new String("font-indent-right"); // 50;

	/** Direction to do indentation. */
	private int direction;

	/**
	 * Creates a new IndentAction.
	 *
	 * @param nm the action name
	 */
	public IndentAction(String nm) {
		super(nm);

		if (nm.equals(LEFT)) {
			this.direction = -50; // remove indentation
		} else {
			this.direction = 50; // add indentation
		}
	}

	/**
	 * Sets the text to the indentation specified.
	 *
	 * @param e the action event
	 */
	public void actionPerformed(ActionEvent e) {
		JEditorPane editor = getEditor(e);
		JTextComponent textPane = getTextComponent(e);

		if (editor != null
			&& textPane != null
			&& textPane instanceof JTextPane) {
			AttributeSet attr = ((JTextPane) textPane).getParagraphAttributes();

			float indent = StyleConstants.getLeftIndent(attr) + this.direction;
			indent = (indent >= 0) ? indent : 0;

			SimpleAttributeSet sas = new SimpleAttributeSet();
			StyleConstants.setLeftIndent(sas, indent);
			setParagraphAttributes(editor, sas, false);
		} else {
			UIManager.getLookAndFeel().provideErrorFeedback(editor);
		}
	}
}
