/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Feb 21, 2003
 * Copyright (C) 2002  Aditisoft Inc
 */
package com.aditisoft.editor;

import java.awt.BorderLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import com.aditisoft.editor.jedit.HTMLTokenMarker;
import com.aditisoft.editor.jedit.JEditTextArea;
import com.aditisoft.editor.jedit.XMLTokenMarker;

public class JEditPanel extends JPanel implements IEditorTools  {

	/** Editor Component */
	JEditTextArea mEditor;

	public static final int C_TOKEN_MARKER_TEXT = 0;
	public static final int C_TOKEN_MARKER_HTML = 1;
	public static final int C_TOKEN_MARKER_XML = 2;

	public JEditPanel(IFileActionsListener fileActions) {
		super();
		mEditor = new JEditTextArea();

		ModFlowLayout layoutManager = new ModFlowLayout(ModFlowLayout.LEFT);
		layoutManager.setParent(this);
		JPanel toolBarPanel = new JPanel();
		toolBarPanel.setLayout(layoutManager);
		toolBarPanel.add(new FileToolbar(fileActions));
		toolBarPanel.add(new EditToolbar(mEditor));
		toolBarPanel.add(new SearchToolbar( this));

		setLayout(new BorderLayout());
		add(toolBarPanel, BorderLayout.NORTH);
		add(new JScrollPane(mEditor), BorderLayout.CENTER);
		mEditor.setText("");
	}

	/**
	 * Method getContentText.
    * Method getContentText. Use this method to get contents of Document edited.
	 * @return String
	 */
	public String getContentText() {
		return mEditor.getText();
      
	}
	/**
	 * Method setContentText. Use this method to set contents for Document to edit.
	 */
	public void setContentText(String content) {
		mEditor.setText(content);
      mEditor.setFirstLine(0);

	}

	/**
	  * By setting TokenMarker, Editor provides syntext highlighting.
	  */
	public void setTokenMarket(int tokenMarker) {
		switch (tokenMarker) {
			case C_TOKEN_MARKER_HTML :
				mEditor.setTokenMarker(new HTMLTokenMarker());
				break;
			case C_TOKEN_MARKER_XML :
				mEditor.setTokenMarker(new XMLTokenMarker());
				break;
			default :
				//Do not set any thing for Pain text with no token marker
				break;
		}
	}
      public void showFindDialog() {
      SearchDialog searchDialog = new SearchDialog(this, mEditor);
      searchDialog.show();
   }
   
   public void showReplaceDialog() {
      ReplaceDialog replaceDialog = new ReplaceDialog(this, mEditor);
      replaceDialog.show();
   }

}
