package com.aditisoft.editor;

import java.awt.Component;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.EventObject;

import javax.swing.JPopupMenu;

/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Dec 5, 2002
 * Copyright (C) 2002  Aditisoft Inc
 * @author Anil K Patel
 */

/**
 * Listener to capture key events. 
 */
public class KeyEventListener implements KeyListener {
	/** Execute actions of editor. */
	private final EditorActions mEditorActions;

	/**
	 * Create instance of KeyEventListener.
	 * @param editorActions
	 * @param fileActions
	 */
	public KeyEventListener(EditorActions editorActions) {
		mEditorActions = editorActions;

	}
	/**
	 * @see java.awt.event.KeyListener#keyTyped(KeyEvent)
	 */
	public void keyTyped(KeyEvent e) {
	}

	/**
	 * @see java.awt.event.KeyListener#keyPressed(KeyEvent)
	 */
	public void keyPressed(KeyEvent e) {

		if ((e.getKeyCode() == e.VK_Z) && e.isControlDown()) {
			mEditorActions.undo();
		}
		else if ((e.getKeyCode() == e.VK_Y) && e.isControlDown()) {
			mEditorActions.redo();
		}
		else if ((e.getKeyCode() == e.VK_B) && e.isControlDown()) {
			mEditorActions.setBold();
		}
		else if ((e.getKeyCode() == e.VK_I) && e.isControlDown()) {
			mEditorActions.setItalic();
		}
		else if ((e.getKeyCode() == e.VK_U) && e.isControlDown()) {
			mEditorActions.setUnderline();
		}
		else if ((e.getKeyCode() == e.VK_S) && e.isControlDown()) {
			getFileActionsListener(e).save();
		}
		else if ((e.getKeyCode() == e.VK_F) && e.isControlDown()) {
			getEditorTools(e).showFindDialog();
		}
		else if ((e.getKeyCode() == e.VK_H) && e.isControlDown()) {
			getEditorTools(e).showReplaceDialog();
		}
	}

	/**
	 * @see java.awt.event.KeyListener#keyReleased(KeyEvent)
	 */
	public void keyReleased(KeyEvent e) {
	}

	public static IFileActionsListener getFileActionsListener(EventObject evt) {
		if (evt != null) {
			Object o = evt.getSource();
			if (o instanceof Component) {
				// find the parent text area
				Component c = (Component) o;
				for (;;) {
					if (c instanceof IFileActionsListener)
						return (IFileActionsListener) c;
					else if (c == null)
						break;
					if (c instanceof JPopupMenu)
						c = ((JPopupMenu) c).getInvoker();
					else
						c = c.getParent();
				}
			}
		}
		// this shouldn't happen
		System.err.println("BUG: getFileActionsListener() returning null");
		return null;
	}
	public static IEditorTools getEditorTools(EventObject evt) {
		if (evt != null) {
			Object o = evt.getSource();
			if (o instanceof Component) {
				// find the parent text area
				Component c = (Component) o;
				for (;;) {
					if (c instanceof IEditorTools)
						return (IEditorTools) c;
					else if (c == null)
						break;
					if (c instanceof JPopupMenu)
						c = ((JPopupMenu) c).getInvoker();
					else
						c = c.getParent();
				}
			}
		}
		// this shouldn't happen
		System.err.println("BUG: getEditorTools() returning null");
		return null;
	}

}
