package com.aditisoft.editor;

import java.awt.event.ActionEvent;

import javax.swing.JEditorPane;
import javax.swing.UIManager;
import javax.swing.text.MutableAttributeSet;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.html.HTML;
import javax.swing.text.html.HTMLEditorKit;

/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * A HTMLEditorKit.HTMLTextAction used in
 * {@link com.aditisoft.editor.EditorActions EditorActions} to change the
 * style of the text to be a link.
 */
public class LinkAction extends HTMLEditorKit.HTMLTextAction {

	/** The String representing this action. */
	public static final String LINK_ACTION = new String("html-link");

	/** The URL for the link. */
	private String href;

	/**
	 * Creates a new LinkAction.
	 *
	 * @param href the URL for the link.
	 */
	public LinkAction(String href) {
		super(LINK_ACTION);
		this.href = href;
	}

	/**
	 * Sets the text to a link.
	 *
	 * @param e the action event
	 */
	public void actionPerformed(ActionEvent e) {
		JEditorPane editor = getEditor(e);
		if (editor != null) {
			HTMLEditorKit kit = getHTMLEditorKit(editor);
			MutableAttributeSet attr = kit.getInputAttributes();

			if (null != href) {
				if (href.equals("") == false) {
					// Sets up an AttributeSet for the location of the link
					SimpleAttributeSet linkLocation = new SimpleAttributeSet();
					linkLocation.addAttribute(HTML.Attribute.HREF, href);

					// Sets up the link's HTML.Tag.A using the attributes from linkLocation
					SimpleAttributeSet sas = new SimpleAttributeSet();
					sas.addAttribute(HTML.Tag.A, linkLocation);
					setCharacterAttributes(editor, sas, false);
				} else {
					// The href was empty, so remove the HTML.Tag.A attribute
					attr.removeAttribute(HTML.Tag.A);
					setCharacterAttributes(editor, attr, true);
				}
			}

		} else {
			UIManager.getLookAndFeel().provideErrorFeedback(editor);
		}
	}
}
