/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Feb 04, 2003
 * Copyright (C) 2002  Aditisoft Inc
 */

package com.aditisoft.editor;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

import com.aditisoft.ui.GenericListener;

/**
 * @author Harsh Vijaywargiya Feb 04, 2003 3:27:54 PM
 * Dialog window for functionality Find/Replace
 */
public class ReplaceDialog extends JDialog implements ItemListener {

	/** Indicate if search whole word */
	boolean mMatchWholeWord = false;
	/** Editor to execute actions */
	ITextEditor mEditor;

	JTextField mTxtWith;
	JTextField mTxtFind;

	/**
	 * Create an instance of ReplaceDialog.
	 * @param parent Parent component of this dialog window.
	 * @param editor Editor to execute actions
	 */
	public ReplaceDialog(JComponent parent, ITextEditor editor) {
		super(JOptionPane.getFrameForComponent(parent));
		String selectedText = editor.getSelectedText();

		mEditor = editor;
		setTitle("Find And Replace");
		JPanel topPanel = new JPanel();
		topPanel.setLayout(new GridLayout(4, 2));
		JLabel lFind = new JLabel(" Find");
		mTxtFind = new JTextField(15);
		if (selectedText != null) {
			mTxtFind.setText(selectedText);
		}
		topPanel.add(lFind);
		topPanel.add(mTxtFind);

		JLabel lReplace = new JLabel(" Replace With");
		mTxtWith = new JTextField(15);
		topPanel.add(lReplace);
		topPanel.add(mTxtWith);

		topPanel.add(new JLabel());
		topPanel.add(new JLabel());

		JCheckBox matchWord = new JCheckBox("Match Whole Word");
		matchWord.setMnemonic('W');
		matchWord.setEnabled(false);
		matchWord.addItemListener(this);
		topPanel.add(matchWord);
		topPanel.add(new JLabel());

		Box buttonBox = Box.createVerticalBox();
		buttonBox.add(Box.createVerticalStrut(5));

		JButton findNext = new JButton(" Find Next ");
		findNext.addActionListener(GenericListener.createActionListener(this, "findNext"));
		findNext.setMnemonic('F');

		JButton replace = new JButton("  Replace  ");
		replace.addActionListener(GenericListener.createActionListener(this, "replace"));
		replace.setMnemonic('R');

		JButton replaceAll = new JButton("Replace All");
		replaceAll.addActionListener(GenericListener.createActionListener(this, "replaceAll"));
		replaceAll.setMnemonic('A');

		JButton cancel = new JButton("   Cancel  ");
		cancel.addActionListener(GenericListener.createActionListener(this, "cancelBtn"));
		cancel.setMnemonic('C');

		buttonBox.add(findNext);
		buttonBox.add(Box.createVerticalStrut(5));
		buttonBox.add(replace);
		buttonBox.add(Box.createVerticalStrut(5));
		buttonBox.add(replaceAll);
		buttonBox.add(Box.createVerticalStrut(5));
		buttonBox.add(cancel);
		buttonBox.add(Box.createVerticalStrut(5));

		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(topPanel, "Center");
		getContentPane().add(buttonBox, "East");
		setSize(400, 165);
	}

	public int findNext(ActionEvent evt) {
		int findPosition = -1;
		String findWhat = mTxtFind.getText();
		findPosition = mEditor.find(findWhat);
		requestFocus();
		return findPosition;
	}

	public void replace(ActionEvent evt) {
		String selText = mEditor.getSelectedText();
		if (selText != null && !selText.equals("") && selText.length() > 0) {
			int selTextStart = mEditor.getSelectionStart();
			mEditor.setCaretPosition(selTextStart);
			String findWhat = mTxtFind.getText();
			String replaceWith = mTxtWith.getText();
			mEditor.replace(findWhat, replaceWith, false);
		}
		int location = findNext(evt);
		if (location == -1) {
			int option =
				JOptionPane.showConfirmDialog(
					null,
					"Finished Searching \"" + mTxtFind.getText() + "\"\nDo you want to continue?",
					"Find",
					JOptionPane.YES_NO_OPTION,
					JOptionPane.INFORMATION_MESSAGE);

			if (option == JOptionPane.YES_OPTION) {
				mEditor.setCaretPosition(0);
				findNext(evt);
			}
		}
		requestFocus();
	}
	public void replaceAll(ActionEvent evt) {
		String findWhat = mTxtFind.getText();
		String replaceWith = mTxtWith.getText();
		mEditor.replace(findWhat, replaceWith, true);
		requestFocus();
	}
	public void cancelBtn(ActionEvent evt) {
		dispose();
	}

	/**
	 * @see java.awt.event.ItemListener#itemStateChanged(ItemEvent)
	 */
	public void itemStateChanged(ItemEvent ite) {
		JCheckBox box = (JCheckBox) ite.getSource();
		if (box.isSelected()) {
			mMatchWholeWord = true;
		}
		else {
			mMatchWholeWord = false;
		}
	}

}