/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Feb 04, 2003
 * Copyright (C) 2002  Aditisoft Inc
 */
package com.aditisoft.editor;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.Iterator;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

import com.aditisoft.ui.GenericListener;

/**
 * @author Harsh Vijaywargiya Feb 04, 2003 3:27:54 PM
 * Dialog window for functionality Find/Replace
 */
public class SearchDialog extends JDialog implements ActionListener, ItemListener {
	/** Indicate if search whole word */
	private boolean mMatchWholeWord = false;
	private JTextField mTxtFind;
	/** Editor to execute actions */
	private ITextEditor mEditor;
	//HTMLEditor  theEditor;
	/**
	 * Create an instance of SearchDialog.
	 * @param parent Parent component of this dialog window.
	 * @param editor Editor to execute actions
	 */
	public SearchDialog(JComponent parent, ITextEditor editor) {
		super(JOptionPane.getFrameForComponent(parent));
		String selectedText = editor.getSelectedText();
		mEditor = editor;
		setTitle("Find");
		JPanel topPanel = new JPanel();
		JLabel lFind = new JLabel(" Find What : ");
		mTxtFind = new JTextField(15);
		if (selectedText != null) {
			mTxtFind.setText(selectedText);
		}
		topPanel.add(lFind);
		topPanel.add(mTxtFind);
		JPanel buttonPanel = new JPanel();
		JButton findNext = new JButton("Find Next");
		findNext.addActionListener(this);
		findNext.setMnemonic('F');
		JButton cancel = new JButton("Cancel");
		cancel.setMnemonic('C');
		cancel.addActionListener(GenericListener.createActionListener(this, "cancelBtn"));
		buttonPanel.add(findNext);
		buttonPanel.add(cancel);
		getContentPane().setLayout(new GridLayout(3, 1));
		getContentPane().add(topPanel);
		JCheckBox matchWord = new JCheckBox("Match Whole Word Only");
		matchWord.setMnemonic('W');
		matchWord.setEnabled(true);
		matchWord.addItemListener(this);
		getContentPane().add(matchWord);
		getContentPane().add(buttonPanel);
		setSize(300, 150);
	}

	public void cancelBtn(ActionEvent event) {
      dispose();
//		setVisible(false);
	}

	/**
	 * @see java.awt.event.ActionListener#actionPerformed(ActionEvent)
	 */
	public void actionPerformed(ActionEvent evt) {
		findNext();
	}

	private void findNext() {
		String findWhat = mTxtFind.getText();
		if (mMatchWholeWord) {
			findWhat = " " + findWhat + " ";
		}
		int location = mEditor.find(findWhat);
		if (location == -1) {
			int option =
				JOptionPane.showConfirmDialog(
					null,
					"Finished Searching \"" + findWhat + "\"\nDo you want to continue?",
					"Find",
					JOptionPane.YES_NO_OPTION,
					JOptionPane.INFORMATION_MESSAGE);

			if (option == JOptionPane.YES_OPTION) {
				mEditor.setCaretPosition(0);
				findNext();
			}
		}
		super.repaint();
      this.requestFocus();
	}

	/**
	 * @see java.awt.event.ItemListener#itemStateChanged(ItemEvent)
	 */
	public void itemStateChanged(ItemEvent ite) {
		JCheckBox box = (JCheckBox) ite.getSource();
		if (box.isSelected())
			mMatchWholeWord = true;
		else
			mMatchWholeWord = false;
	}

}