/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Dec 5, 2002
 * Copyright (C) 2002  Aditisoft Inc
 * @author Anil K Patel
 */
package com.aditisoft.editor;

import java.awt.event.ActionEvent;

import javax.swing.JEditorPane;
import javax.swing.UIManager;
import javax.swing.text.MutableAttributeSet;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledEditorKit;

/**
 * A StyledEditorKit.StyledTextAction used in
 * {@link com.aditisoft.editor.EditorActions EditorActions} to change the
 * style of the text to Superscript.
 */
public class SuperscriptAction extends StyledEditorKit.StyledTextAction
{

	/** String representing this action. */
	public static final String SUPERSCRIPT_ACTION = new String("font-superscript");

	/**
	 * Creates a new SuperscriptAction.
	 */
	public SuperscriptAction()
	{
		super(SUPERSCRIPT_ACTION);
	}

	/**
	 * Sets the font to superscript.
	 *
	 * @param e the action event
	 */
	public void actionPerformed(ActionEvent e)
	{
		JEditorPane editor = getEditor(e);
		if (editor != null)
		{
			StyledEditorKit kit = getStyledEditorKit(editor);
			MutableAttributeSet attr = kit.getInputAttributes();

			boolean sup = (StyleConstants.isSuperscript(attr)) ? false : true;

			SimpleAttributeSet sas = new SimpleAttributeSet();
			StyleConstants.setSuperscript(sas, sup);
			setCharacterAttributes(editor, sas, false);
		} else
		{
			UIManager.getLookAndFeel().provideErrorFeedback(editor);
		}
	}
}
