//Title:        Curriculum Development Tool
//Copyright:    Copyright (c) 2001
//Author:       David Bradford - dbrad@medstat.med.utah.edu
//Company:      Knowledge Weavers - http://medstat.med.utah.edu/kw/
//File:         editor/TableWizard.java
//Description:  1st page in table wizard

package com.aditisoft.editor;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 * This is the first frame in the Table Wizard.  The Wizard uses a wizard framework I set up
 * from a magazine article I read.  You can read about that in the actual code for the wizard.
 * Anyway this part of the wizard lets the user specify things about the table.  It uses the
 * TableViewer to let the user see how the table will look.  It lets the user add/remove/span
 * rows/columns and lets them say whether or not they want a border.
 *
 * @version 1.0
 * @author David Bradford
 */
public class TableWizard extends WizardFrame implements ActionListener {
	/** Lets the user view the table */
	private TableViewer table;
	/** Checks where the user wants a border around the table or not. */
	private JCheckBox showBorder = new JCheckBox("Show Border");

	/**
	 * Create the TableWizard.
	 *
	 * @param parent frame that contains this wizard.
	 */
	public TableWizard(Frame parent) {
		super(parent);
		table = new TableViewer();
		init();
	}

	/**
	 * Sets the layout of this part of the wizard.  This function is part of the wizard framework.
	 */
	public void customize() {
		setTitle("Table Wizard");
		setFrameLabel1("Customize Border");
		showPreviousButton(false);
		showFinishButton(false);

		centerPanel.setLayout(new BorderLayout());

		JPanel panel = new JPanel(new GridLayout(2, 0));
		panel.add(table);

		JPanel buttonPanel = new JPanel(new GridLayout(3, 0));

		JPanel rowPanel = new JPanel();
		JButton addRow = new JButton("Add Row");
		addRow.addActionListener(this);
		rowPanel.add(addRow);
		JButton removeRow = new JButton("Remove Row");
		removeRow.addActionListener(this);
		rowPanel.add(removeRow);
		JButton spanRow = new JButton("Span Row");
		spanRow.addActionListener(this);
		rowPanel.add(spanRow);
		buttonPanel.add(rowPanel);

		JPanel colPanel = new JPanel();
		JButton addCol = new JButton("Add Column");
		addCol.addActionListener(this);
		colPanel.add(addCol);
		JButton removeCol = new JButton("Remove Column");
		removeCol.addActionListener(this);
		colPanel.add(removeCol);
		JButton spanCol = new JButton("Span Column");
		spanCol.addActionListener(this);
		colPanel.add(spanCol);
		buttonPanel.add(colPanel);
		buttonPanel.add(showBorder);

		panel.add(buttonPanel);

		centerPanel.add(panel, BorderLayout.CENTER);
	}

	/**
	 * This handles what happens when the user clicks the next button.  It prepares for the next
	 * frame in the wizard and then creates it.
	 */
	public void nextAction() {
		StringBuffer s = new StringBuffer();
		s.append("<table");
		if (showBorder.isSelected()) {
			s.append(" border=\"1\"");
		} else {
			s.append(" border=\"1.0\"");
		}
		s.append(">\n");
		try {
			s.append(table.toString());
		} catch (Exception e) {
			e.printStackTrace();
		}
		s.append("\n</table>");
		putData("tag", s.toString());
		setVisible(false);
		pushFrame(this);
		new TableWizard1((JFrame) getData().get("parentFrame"));
	}

	/**
	 * This handles button clicks for adding/removing/spaning rows/columns.
	 *
	 * @param event Info about what button was clicked.
	 */
	public void actionPerformed(ActionEvent event) {
		try {
			if (event.getActionCommand().equals("Add Row")) {
				table.addRow();
			} else if (event.getActionCommand().equals("Remove Row")) {
				table.removeRow();
			} else if (event.getActionCommand().equals("Span Row")) {
				table.spanRow();
			} else if (event.getActionCommand().equals("Add Column")) {
				table.addCol();
			} else if (event.getActionCommand().equals("Remove Column")) {
				table.removeCol();
			} else if (event.getActionCommand().equals("Span Column")) {
				table.spanCol();
			}
		} catch (Exception e) {
			e.printStackTrace(System.out);
		}
	}
}