//Title:        Curriculum Development Tool
//Copyright:    Copyright (c) 2001
//Author:       David Bradford - dbrad@medstat.med.utah.edu
//Company:      Knowledge Weavers - http://medstat.med.utah.edu/kw/
//File:         editor/Vector2d.java
//Description:  2-d vector used in table wizard

package com.aditisoft.editor;

import java.util.Vector;

/**
 * This class is a 2-d vector since there is none built into java.  It is only for the TableViewer.
 * You probably won't want to use this for other things since it doesn't work exactly like a 2-d
 * vector should.  The 2-d vector is represented by a vector of vectors.
 *
 * @version 1.0
 * @author David Bradford
 */
public class Vector2d {
	/** A vector of vectors that contains data. */
	private Vector data = new Vector();
	/** Width of 2-d vector. */
	private int width;
	/** Height of 2-d vector. */
	private int height;

	/**
	 * Creates a 2-d vector with user-specified width and height.
	 *
	 * @param width Width of 2-d Vector.
	 * @param height Height of 2-d Vector.
	 */
	public Vector2d(int width, int height) {
		this.width = width;
		this.height = height;
		data.setSize(width);
		for (int i = 0; i < width; i++) {
			Vector v = new Vector(height);
			data.add(i, v);
			for (int j = 0; j < height; j++) {
				v.add(j, null);
			}
		}
	}

	/**
	 * Gets the element at x, y.
	 *
	 * @param x X coordinate of the item you want.
	 * @param y Y coordinate of the item you want.
	 * @return Item at (x, y).
	 */
	Object elementAt(int x, int y) {
		Vector v = (Vector) data.elementAt(x);
		return v.elementAt(y);
	}

	/**
	 * Adds an item at (x, y).
	 *
	 * @param x X coordinate of the item to add.
	 * @param y Y coordinate of the item to add.
	 * @param o Item to add.
	 */
	void add(int x, int y, Object o) {
		if (x >= width) {
			changeSize(x + 1, height);
		}
		Vector v = (Vector) data.elementAt(x);
		if (y >= height) {
			changeSize(width, y + 1);
		}
		v.set(y, o);
	}

	/**
	 * Gets the width of the 2-d vector.
	 *
	 * @return Width of vector.
	 */
	public int getWidth() {
		return width;
	}

	/**
	 * Gets the height of the 2-d vector.
	 *
	 * @return Height of vector.
	 */
	public int getHeight() {
		return height;
	}

	/**
	 * Changes the size of the vector to w by h.
	 *
	 * @param w New width of vector.
	 * @param h New height of vector.
	 */
	private void changeSize(int w, int h) {
		for (int i = 0; i < w; i++) {
			if (i < width) {
				Vector v = (Vector) data.elementAt(i);
				for (int j = height; j < h; j++) {
					v.add(j, null);
				}
			} else {
				Vector v = new Vector(h);
				data.add(i, v);
				for (int j = 0; j < h; j++) {
					v.add(j, null);
				}
			}
		}
		width = w;
		height = h;
	}
}
