/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * Created on Feb 24, 2003
 * Copyright (C) 2002  Aditisoft Inc
 * @author Anil K Patel 
 *  * Applet host editor and toolbar. This applet is intended to be tightly integrated with OpenCMS. 
 * For reading and saving files from and to the OpenCMS server, This applet need a EditAction command controller. 
 * Action commands can be like "read", "save", etc.
 * This applet sends request using Http FormPost method, See "doPostAction" method.
 * This applet at least following paramters to be passed to it.
 * Path to the file to be edited, Parameter "file"
 * String Full URL to the EditAction command controller, Parameter "editActionCC" 
 */
package com.aditisoft.editor.applet;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.JApplet;

import netscape.javascript.JSObject;

import com.aditisoft.editor.EditorActionConstants;

public abstract class FileEditorApplet extends JApplet {

	/** Filename in VFS that has to be edited. */
	protected String mEditFile = "";
	/** Complete URL of command controller */
	protected URL mEditorActionURL = null;
	protected String mEditorActionURLString = "";

	protected abstract void setFileContent(FormPoster poster);
	protected abstract void readParameterValues();

	/**
	 * <SCRIPT>
	function exitwindow()
	{
	history.back();
	}
	</SCRIPT>
	
	*/
	public void exit() {
		JSObject win = JSObject.getWindow(this);
		win.call("exitwindow", null);
	}
	/**
	 * Method ifReadRequested indicate if request to save content on server.
	 * @param action action that user requested.
	 * @return boolean
	 */
	public boolean ifSaveRequested(String action) {
		return ((action != null) && (EditorActionConstants.EDIT_ACTION_SAVE.equals(action)));
	}

	/**
	 * Method ifReadRequested indicate if request is for reading content from server.
	 * @param action action that user requested.
	 * @return boolean
	 */
	public boolean ifReadRequested(String action) {
		return ((action != null) && (EditorActionConstants.EDIT_ACTION_READ.equals(action)));
	}

	/**
	 * Always use this method to get URL to the server. Do not refer to mEditorActionURL  directly, 
	 * It may not be initialized.
	 */
	protected URL getEditorActionURL() {
		if (mEditorActionURL == null) {
			try {
				String sURL = mEditorActionURLString;
				mEditorActionURL = new URL(sURL);
			}
			catch (MalformedURLException ex) {
				//May want to do something better then this
				ex.printStackTrace();
			}
		}
		return mEditorActionURL;
	}

	/**
	 * doPostAction is equivalent to posting a HTML form from web browser
	 * @param action String value of the command action to be executed on server 
	 *                          eg: value of contant C_EDIT_ACTION_SAVE
	 */
	protected String doPostAction(String action) {
		StringBuffer outBuffer = new StringBuffer();
		if (getEditorActionURL() != null) {
			FormPoster poster = new FormPoster(getEditorActionURL());
			//Adding parameters value to be send to server
			poster.add(EditorActionConstants.PARA_FILE, mEditFile);
			poster.add(EditorActionConstants.PARA_ACTION, action);

			//This is added for request parameters specific to Save user action                   
			if (ifSaveRequested(action)) {
				//This method in overridden in subclass
				setFileContent(poster);
			}
			try {
				// Sending HTTPRequest
				InputStream in = poster.post();
				in = new BufferedInputStream(in);
				// Getting HTTPResponse, Read the response
				InputStreamReader r = new InputStreamReader(in);
				int c;
				while ((c = r.read()) != -1) {
					outBuffer.append((char) c);
				}
				in.close();
			}
			catch (IOException e) {
				//May want to do something better then this
				e.printStackTrace();
			}
		}
		return outBuffer.toString();
	}

	/**
	 * Get text to display in Editor. 
	 */
	protected String getEditText() {
		String s = doPostAction(EditorActionConstants.EDIT_ACTION_READ);
		return s;
	}

	/**
		* Save Document to the server.
		*/
	public void save() {
		doPostAction(EditorActionConstants.EDIT_ACTION_SAVE);
	}

	public void saveExit() {
		save();
		exit();
	}

}
