package com.aditisoft.editor.applet;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.net.URL;
import java.net.URLConnection;
/**This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * @author Anil K Patel Dec 02 2002
 * Copyright (C) 2002 Aditisoft Inc
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 * Code adopted from JAVA Network Programming 2e Example 15-8
 */

/**
 * This class post http request on server.
 */
public class FormPoster {
	/** Complete URL of request. */
	private URL url;
	/** Storage to append parameters. */
	private QueryString query = new QueryString();

	/**
	 * Create an instance of FormPoster .
	 * @param url
	 * @throws IllegalArgumentException
	 */
	public FormPoster(URL url) throws IllegalArgumentException {
		if (!url.getProtocol().toLowerCase().startsWith("http")) {
			throw new IllegalArgumentException("Posting only works for http URLs");
		}
		this.url = url;
	}

	/**
	 * Set HttpRequest parameter values as Name value pair.
	 * @param name
	 * @param value
	 */
	public void add(String name, String value) {
		query.add(name, value);
	}

	/**
	 * Gets the URL associated with this poster.
	 * @return URL
	 */
	public URL getURL() {
		return this.url;
	}

	/**
	 * Do HTTP form submit using POST method.  Parameter values set using "add" method will be send in request.
	 */
	public InputStream post() throws IOException {
		// open the connection and prepare it to POST
		URLConnection uc = url.openConnection();
		uc.setUseCaches(false);
		//prepare it to POST
		uc.setDoOutput(true);        
		ByteArrayOutputStream byteStream = new ByteArrayOutputStream(512);
		// Grows if necessary
		PrintWriter out = new PrintWriter(byteStream, true);
		// Write POST data into local buffer		
		out.print(query.toString());
		out.flush(); // Flush since above used print, not println
		// POST requests are required to have Content-Length
		String lengthString = String.valueOf(byteStream.size());
		uc.setRequestProperty("Content-Length", lengthString);
		uc.setRequestProperty(
			"Content-Type",
			"application/x-www-form-urlencoded");
		// Write POST data to real output stream
		byteStream.writeTo(uc.getOutputStream());
		InputStream in = uc.getInputStream();

		// Return the response
		return in;
	}
}
