/**
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* For further information about OpenCms, please see the
* OpenCms Website: http://www.opencms.org
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.aditisoft.editor.applet;
/**
 * @author Anil K Patel Dec 04 2002
 * Copyright (C) 2002 Aditisoft Inc
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 */
import java.awt.BorderLayout;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.JApplet;

import netscape.javascript.JSObject;

import com.aditisoft.editor.EditorActionConstants;
import com.aditisoft.editor.HTMLEditorPanel;
import com.aditisoft.editor.IFileActionsListener;

/**
 * Applet host editor and toolbar. This applet is intended to be tightly integrated with OpenCMS. 
 * For reading and saving files from and to the OpenCMS server, This applet need a EditAction command controller. 
 * Action commands can be like "read", "save", etc.
 * This applet sends request using Http FormPost method, See "doPostAction" method.
 * This applet at least following paramters to be passed to it.
 * Path to the file to be edited, Parameter "file"
 * String Full URL to the EditAction command controller, Parameter "editActionCC" 
 * The response stream from editActionCC should contain only the contents of the file to be edited.
 * e.g "http://localhost:8080/opencms/opencms/testpages/editoractionplainmaster.html"
 * TokenMarker type, "tokenMarker" 
 * 
 * Modified Jan 25 2003
 * Added Support to Handle Page Attribute,  like title, template
 * Modified the Structure of Data file transferred between Applet and Server.
 * New Format is called CmsDocument.
 * It had been Flat in nature to keep parsing easy.
 * 
 * This document can be modified to add more file attributes
 * 
 */
public class WYSIWYGEditorApplet extends FileEditorApplet implements IFileActionsListener {

	/** Editor Component */
	HTMLEditorPanel mEditor;

	/**
	 * Read all parameters pass to this applet.
	 */
	protected void readParameterValues() {
		mEditFile = getParameter(EditorActionConstants.PARA_FILE);
		mEditorActionURLString = getParameter(EditorActionConstants.PARA_EDIT_ACTION_CC);
	}

	/**
	 * @see java.applet.Applet#init()
	 */
	public void init() {
		getContentPane().setLayout(new BorderLayout());
		mEditor = new HTMLEditorPanel(this);
		readParameterValues();
		getContentPane().add(mEditor, BorderLayout.CENTER);
		mEditor.setCmsDocument(getEditText());
	}

	protected void setFileContent(FormPoster poster) {
		String content = mEditor.getContentText();
		poster.add(EditorActionConstants.PARA_CONTENT, content);
		poster.add(EditorActionConstants.PARA_MASTER_TEMPLATE, mEditor.getMasterTemplate());
		poster.add("title", mEditor.getTitle());
	}

}
